/******************************************************************************
Author:         David Szybala
Website:        www.davidszybala.com
Alt Website:    www.twistedgerbil.com
Program:        rgb_masker.ms
Date:           12/03/09
Description:    This script will assign a red, blue or green shader to the
                selected objects
******************************************************************************/

try (destroyDialog rgb_masker_rollout) catch()


struct RGBMasker
(
    mask_materials = #(undefined, undefined, undefined, undefined, undefined, undefined),
    mask_names = #("Mask_Red", "Mask_Green", "Mask_Blue", "Mask_Black", "Mask_White", "Mask_Multi"),
    mask_colors = #(color 255 0 0, color 0 255 0, color 0 0 255, color 0 0 0, color 255 255 255, undefined),
    
    /**************************************************************************
    Returns a mask standard material with color 'mask_color' and name
    'material_name'
    **************************************************************************/
    fn get_mask_material mask_color material_name =
    (
        local mask_material = StandardMaterial()
        mask_material.selfIllumAmount = 100
        mask_material.twoSided = true
        mask_material.diffuse = mask_color
        mask_material.name = material_name
        
        mask_material --return value
    ), --end fn
    
    /**************************************************************************
    Returns a mask multi material with name 'material_name'
    **************************************************************************/
    fn get_mask_multi_material material_name =
    (
        local mask_material = multimaterial()
        mask_material.numsubs = 4
        mask_material[1] = this.mask_materials[1]
        mask_material[2] = this.mask_materials[2]
        mask_material[3] = this.mask_materials[3]
        mask_material[4] = this.mask_materials[4]
        mask_material.name = material_name
        
        mask_material --return value
    ), --end fn
    
    /**************************************************************************
    Prepares the masker for first time operation. Creates standard masks and
    searches for existing masks
    **************************************************************************/
    fn initialize_masker =
    (
        local all_material_names = for current in sceneMaterials collect current.name
        
        for i = 1 to 5 do
            this.mask_materials[i] = this.get_mask_material this.mask_colors[i] this.mask_names[i]
        
        for i = 1 to 6 do
        (
            index = findItem all_material_names this.mask_names[i]
            
            if index > 0 do
                this.mask_materials[i] = sceneMaterials[index]
        ) --end for
        
        if this.mask_materials[6] == undefined do
            this.mask_materials[6] = this.get_mask_multi_material this.mask_names[6]
    ) --end fn
) --end struct


( --put script into local scope
    global rgb_masker_rollout
    local rgb_masker_ini = getDir #plugcfg + "\\RGBMasker.ini"
    local rgb_masker_position
    
    rollout rgb_masker_rollout "RGB Masker"
    (
        local masker = RGBMasker()
        
        group "Assign Selection:"
        (
            button mask_red_button "Red Mask" align:#left width:125
            button mask_green_button "Green Mask" align:#left width:125
            button mask_blue_button "Blue Mask" align:#left width:125
            button mask_black_button "Black Mask" align:#left width:125
            button mask_white_button "White Mask" align:#left width:125
            button mask_multi_button "Multi Mask" align:#left width:125
        ) --end group
        
        /**********************************************************************
        UI open event handler. Prepares the UI for first time open
        **********************************************************************/
        on rgb_masker_rollout open do
            masker.initialize_masker()
        
        /**********************************************************************
        UI move event handler. Stores the curent position of the UI
        **********************************************************************/
        on rgb_masker_rollout moved pos do
            setIniSetting rgb_masker_ini "Dialog" "Position" (pos as string)
        
        /**********************************************************************
        Mask event handlers. Applies the appropriate mask to the selection
        **********************************************************************/
        on mask_red_button pressed do
            selection.material = masker.mask_materials[1]
        on mask_green_button pressed do
            selection.material = masker.mask_materials[2]
        on mask_blue_button pressed do
            selection.material = masker.mask_materials[3]
        on mask_black_button pressed do
            selection.material = masker.mask_materials[4]
        on mask_white_button pressed do
            selection.material = masker.mask_materials[5]
        on mask_multi_button pressed do
            selection.material = masker.mask_materials[6]
    ) --end rollout
    
    rgb_masker_position = execute (getIniSetting rgb_masker_ini "Dialog" "Position")
    if rgb_masker_position == OK do rgb_masker_position = [100,100]
    if rgb_masker_position.x > sysinfo.desktopsize.x - 150 do
        rgb_masker_position.x = sysinfo.desktopsize.x - 155
    if rgb_masker_position.y > sysinfo.desktopsize.y - 245 do
        rgb_masker_position.y = sysinfo.desktopsize.y - 245
    if rgb_masker_position.x < 0 do rgb_masker_position.x = 0 
    if rgb_masker_position.y < 0 do rgb_masker_position.y = 0
    createDialog rgb_masker_rollout 150 185 rgb_masker_position.x rgb_masker_position.y
) --end local scope